velix_i18n library

Classes

AssetTranslationLoader
CurrencyFormatter
A Formatter that is able to format currency numbers with the name "currency". Supported arguments are:
DateFormatter
A Formatter that is able to format DateTimes with the format name "date" Supported arguments are:
Formatter
a Formatter is used to format placeholders.
I18N
I18n is a central singleton that controls the overall localization process.
I18nDelegate
A specialized LocalizationsDelegate that will load all necessary localizations
I18NState
LocaleManager
A LocaleManager keeps track of the current locale and can notify listeners about changes,.
NumberFormatter
A Formatter that is able to format numbers with the name "number". Supported arguments are:
TranslationLoader
A TranslationLoader loads translations.
TypeViolationTranslationProvider

Extensions

I18nStringExtension on String
extension on string sm which allows a tr() function call

Typedefs

I18NFunction = String Function(Map<String, dynamic> args)
MissingKeyHandler = String Function(String key)
function used to compute a localization in case of missing i18n data